@@ -1,26 +1,25 @@
-/*
- * baobab-utils.c
- * This file is part of baobab
+/* Copyright (C) 2005-2006 Fabio Marzocca <thesaltydog@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2005-2006 Fabio Marzocca  <thesaltydog@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or modify
+ * MATE Utils is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -71,7 +70,7 @@ baobab_get_filesystem (BaobabFS *fs)
 	g_free (mountentries);
 }
 
-void
+static void
 filechooser_cb (GtkWidget *chooser,
                 gint response,
                 gpointer data)
@@ -145,24 +144,6 @@ on_toggled (GtkToggleButton *togglebutton, gpointer dialog)
 					  (GTK_FILE_CHOOSER (dialog)));
 }
 
-void
-set_ui_action_sens (const gchar *name, gboolean sens)
-{
-	GtkAction *a;
-
-	a = GTK_ACTION (gtk_builder_get_object (baobab.main_ui, name));
-	gtk_action_set_sensitive (a, sens);
-}
-
-void
-set_ui_widget_sens (const gchar *name, gboolean sens)
-{
-	GtkWidget *w;
-
-	w = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, name));
-	gtk_widget_set_sensitive (w, sens);
-}
-
 gboolean
 show_bars (GtkTreeModel *mdl,
 	   GtkTreePath *path,
