@@ -1,26 +1,25 @@
-/*
- * baobab.c
- * This file is part of baobab
+/* Copyright (C) 2005-2006 Fabio Marzocca <thesaltydog@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2005-2006 Fabio Marzocca  <thesaltydog@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or modify
+ * MATE Utils is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -38,6 +37,9 @@
 #include "baobab-ringschart.h"
 
 #define BAOBAB_UI_RESOURCE "/org/mate/disk-usage-analyzer/baobab-main-window.ui"
+#define GET_WIDGET(x) (GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, (x))))
+#define GET_ACTION(x) (GTK_ACTION (gtk_builder_get_object (baobab.main_ui, (x))))
+#define GET_TOGGLE_ACTION(x) (GTK_TOGGLE_ACTION (gtk_builder_get_object (baobab.main_ui, (x))))
 
 static void push_iter_in_stack (GtkTreeIter *);
 static GtkTreeIter pop_iter_from_stack (void);
@@ -137,27 +139,27 @@ check_menu_sens (gboolean scanning)
 			gtk_main_iteration ();
 
 		baobab_set_statusbar (_("Scanning..."));
-		set_ui_action_sens ("expand_all", TRUE);
-		set_ui_action_sens ("collapse_all", TRUE);
+		gtk_action_set_sensitive (GET_ACTION ("expand_all"), TRUE);
+		gtk_action_set_sensitive (GET_ACTION ("collapse_all"), TRUE);
 	}
 
 	has_current_location = baobab.current_location != NULL;
 
-	set_ui_action_sens ("menuscanhome", !scanning);
-	set_ui_action_sens ("menuallfs", !scanning);
-	set_ui_action_sens ("menuscandir", !scanning);
-	set_ui_action_sens ("menustop", scanning);
-	set_ui_action_sens ("menurescan", !scanning && has_current_location);
-	set_ui_action_sens ("preferenze1", !scanning);
-	set_ui_action_sens ("menu_scan_rem", !scanning);
-	set_ui_action_sens ("ck_allocated", !scanning && baobab.is_local);
+	gtk_action_set_sensitive (GET_ACTION ("menuscanhome"), !scanning);
+	gtk_action_set_sensitive (GET_ACTION ("menuallfs"), !scanning);
+	gtk_action_set_sensitive (GET_ACTION ("menuscandir"), !scanning);
+	gtk_action_set_sensitive (GET_ACTION ("menustop"), scanning);
+	gtk_action_set_sensitive (GET_ACTION ("menurescan"), !scanning && has_current_location);
+	gtk_action_set_sensitive (GET_ACTION ("preferenze1"), !scanning);
+	gtk_action_set_sensitive (GET_ACTION ("menu_scan_rem"), !scanning);
+	gtk_action_set_sensitive (GET_ACTION ("ck_allocated"), !scanning && baobab.is_local);
 
-	set_ui_widget_sens ("tbscanhome", !scanning);
-	set_ui_widget_sens ("tbscanall", !scanning);
-	set_ui_widget_sens ("tbscandir", !scanning);
-	set_ui_widget_sens ("tbstop", scanning);
-	set_ui_widget_sens ("tbrescan", !scanning && has_current_location);
-	set_ui_widget_sens ("tb_scan_remote", !scanning);
+	gtk_widget_set_sensitive (GET_WIDGET ("tbscanhome"), !scanning);
+	gtk_widget_set_sensitive (GET_WIDGET ("tbscanall"), !scanning);
+	gtk_widget_set_sensitive (GET_WIDGET ("tbscandir"), !scanning);
+	gtk_widget_set_sensitive (GET_WIDGET ("tbstop"), scanning);
+	gtk_widget_set_sensitive (GET_WIDGET ("tbrescan"), !scanning && has_current_location);
+	gtk_widget_set_sensitive (GET_WIDGET ("tb_scan_remote"), !scanning);
 }
 
 static void
@@ -174,7 +176,6 @@ update_scan_label (void)
 	gchar *total;
 	gchar *used;
 	gchar *available;
-	GtkWidget *label;
 
 		total = g_format_size (baobab.fs.total);
 		used = g_format_size (baobab.fs.used);
@@ -190,9 +191,7 @@ update_scan_label (void)
 	g_free (used);
 	g_free (available);
 
-	label = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "label1"));
-
-	gtk_label_set_markup (GTK_LABEL (label), markup);
+	gtk_label_set_markup (GTK_LABEL (GET_WIDGET ("label1")), markup);
 	g_free (markup);
 }
 
@@ -228,7 +227,7 @@ baobab_scan_location (GFile *file)
 
 	/* check if the file system is local or remote */
 	baobab.is_local = scan_is_local (file);
-	ck_allocated = GTK_TOGGLE_ACTION (gtk_builder_get_object (baobab.main_ui, "ck_allocated"));
+	ck_allocated = GET_TOGGLE_ACTION ("ck_allocated");
 	if (!baobab.is_local) {
 		gtk_toggle_action_set_active (ck_allocated, FALSE);
 		gtk_action_set_sensitive (GTK_ACTION (ck_allocated), FALSE);
@@ -453,7 +452,7 @@ baobab_fill_model (struct chan_data *data)
 
 	hardlinks = g_string_new ("");
 	if (data->tempHLsize > 0) {
-			size = g_format_size (data->tempHLsize);
+		size = g_format_size (data->tempHLsize);
 
 		g_string_assign (hardlinks, "<i>(");
 		g_string_append (hardlinks, _("contains hardlinks for:"));
@@ -649,7 +648,7 @@ baobab_create_toolbar (void)
 	GtkToolItem *item;
 	GtkToolItem *separator;
 
-	toolbar = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "toolbar1"));
+	toolbar = GET_WIDGET ("toolbar1");
 	if (toolbar == NULL) {
 		g_printerr ("Could not build toolbar\n");
 		return;
@@ -679,7 +678,7 @@ baobab_create_toolbar (void)
 			 G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind (baobab.ui_settings,
 			 BAOBAB_SETTINGS_TOOLBAR_VISIBLE,
-			 GTK_TOGGLE_ACTION (gtk_builder_get_object (baobab.main_ui, "view_tb")), "active",
+			 GET_TOGGLE_ACTION ("view_tb"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
 
 }
@@ -687,8 +686,7 @@ baobab_create_toolbar (void)
 static void
 baobab_create_statusbar (void)
 {
-	baobab.statusbar = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui,
-							       "statusbar1"));
+	baobab.statusbar = GET_WIDGET ("statusbar1");
 	if (baobab.statusbar == NULL) {
 		g_printerr ("Could not build statusbar\n");
 		return;
@@ -700,7 +698,7 @@ baobab_create_statusbar (void)
 			 G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind (baobab.ui_settings,
 			 BAOBAB_SETTINGS_STATUSBAR_VISIBLE,
-			 GTK_TOGGLE_ACTION (gtk_builder_get_object (baobab.main_ui, "view_sb")), "active",
+			 GET_TOGGLE_ACTION ("view_sb"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
 }
 
@@ -733,7 +731,6 @@ store_excluded_locations (void)
 {
 	GSList *l;
 	GPtrArray *uris;
-	GSList *uri_list = NULL;
 
 	uris = g_ptr_array_new ();
 
@@ -1074,7 +1071,7 @@ static void
 on_chart_type_change (GtkWidget *combo, gpointer user_data)
 {
 	GtkWidget *chart;
-	guint active;
+	gint active;
 
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
@@ -1104,7 +1101,7 @@ initialize_charts (void)
 	gtk_frame_set_label_align (GTK_FRAME (baobab.chart_frame), 0.0, 0.0);
 	gtk_frame_set_shadow_type (GTK_FRAME (baobab.chart_frame), GTK_SHADOW_IN);
 
-	hpaned_main = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "hpaned_main"));
+	hpaned_main = GET_WIDGET ("hpaned_main");
 	gtk_paned_pack2 (GTK_PANED (hpaned_main),
 			 baobab.chart_frame, TRUE, TRUE);
 	gtk_paned_set_position (GTK_PANED (hpaned_main), 480);
@@ -1119,7 +1116,7 @@ initialize_charts (void)
 			  "changed",
 			  G_CALLBACK (on_chart_type_change), NULL);
 
-	hbox1 = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "hbox1"));
+	hbox1 = GET_WIDGET ("hbox1");
 	gtk_container_add (GTK_CONTAINER (hbox1), baobab.chart_type_combo);
 	gtk_box_set_spacing (GTK_BOX (hbox1), 50);
 	gtk_box_set_child_packing (GTK_BOX (hbox1),
@@ -1231,9 +1228,11 @@ main (int argc, char *argv[])
 	GOptionContext *context;
 	GError *error = NULL;
 
+#ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
 	g_set_application_name (_("Disk Usage Analyzer"));
 
@@ -1283,17 +1282,16 @@ main (int argc, char *argv[])
 	check_menu_sens (FALSE);
 	update_scan_label ();
 
-	baobab.window = GTK_WIDGET (gtk_builder_get_object (baobab.main_ui, "baobab_window"));
+	baobab.window = GET_WIDGET ("baobab_window");
 	gtk_window_set_position (GTK_WINDOW (baobab.window),
 				 GTK_WIN_POS_CENTER);
 
 	baobab.tree_view = create_directory_treeview ();
 
-	set_ui_action_sens ("menurescan", FALSE);
+	gtk_action_set_sensitive (GET_ACTION ("menurescan"), FALSE);
 
 	/* set allocated space checkbox */
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (gtk_builder_get_object (baobab.main_ui,
-							 "ck_allocated")),
+	gtk_toggle_action_set_active (GET_TOGGLE_ACTION ("ck_allocated"),
 				      baobab.show_allocated);
 
 	gtk_widget_show (baobab.window);
