@@ -1,26 +1,27 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* logview-log.c - object representation of a logfile
- *
- * Copyright (C) 1998 Cesar Miquel <miquel@df.uba.ar>
+/* Copyright (C) 1998 Cesar Miquel <miquel@df.uba.ar>
  * Copyright (C) 2008 Cosimo Cecchi <cosimoc@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This file is part of MATE Utils.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 551 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
- * USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <glib.h>
 #include <glib/gi18n.h>
@@ -33,11 +34,6 @@
 #include "logview-log.h"
 #include "logview-utils.h"
 
-G_DEFINE_TYPE (LogviewLog, logview_log, G_TYPE_OBJECT);
-
-#define GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), LOGVIEW_TYPE_LOG, LogviewLogPrivate))
-
 enum {
   LOG_CHANGED,
   LAST_SIGNAL
@@ -93,6 +89,8 @@ typedef struct {
   z_stream zstream;
 } GZHandle;
 
+G_DEFINE_TYPE_WITH_PRIVATE (LogviewLog, logview_log, G_TYPE_OBJECT);
+
 static void
 do_finalize (GObject *obj)
 {
@@ -143,14 +141,12 @@ logview_log_class_init (LogviewLogClass *klass)
                                        NULL, NULL,
                                        g_cclosure_marshal_VOID__VOID,
                                        G_TYPE_NONE, 0);
-
-  g_type_class_add_private (klass, sizeof (LogviewLogPrivate));
 }
 
 static void
 logview_log_init (LogviewLog *self)
 {
-  self->priv = GET_PRIVATE (self);
+  self->priv = logview_log_get_instance_private (self);
 
   self->priv->lines = NULL;
   self->priv->lines_no = 0;
@@ -190,7 +186,7 @@ setup_file_monitor (LogviewLog *log)
     g_error_free (err);
     return;
   }
-  
+
   /* set the rate to 1sec, as I guess it's not unusual to have more than
    * one line written consequently or in a short time, being a log file.
    */
@@ -232,7 +228,7 @@ add_new_days_to_cache (LogviewLog *log, const char **new_lines, guint lines_offs
       log->priv->days = g_slist_append (log->priv->days, logview_utils_day_copy (day));
     } else if (res == 0) {
       last = last_cached->data;
- 
+
       /* update the lines number */
       last->last_line += day->last_line;
     }
@@ -307,7 +303,6 @@ do_read_new_lines (GIOSchedulerJob *io_job,
   log->priv->has_new_lines = FALSE;
 
   /* we'll return only the new lines in the callback */
-  line = g_ptr_array_index (lines, log->priv->lines_no);
   job->lines = (const char **) lines->pdata + log->priv->lines_no;
 
   /* save the new number of days and lines */
@@ -372,13 +367,12 @@ skip_string (GInputStream *is)
 	} while (c != 0);
 
 	return TRUE;
-} 
+}
 
 static gboolean
 read_gzip_header (GInputStream *is,
                   time_t *modification_time)
 {
-  gboolean res;
 	guchar buffer[GZIP_HEADER_SIZE];
 	gssize bytes, to_skip;
 	guint mode;
@@ -409,7 +403,7 @@ read_gzip_header (GInputStream *is,
 		guchar tmp[2];
 
     bytes = g_input_stream_read (is, tmp, 2, NULL, NULL);
-  
+
     if (bytes != 2) {
 			return FALSE;
     }
@@ -495,7 +489,6 @@ static gboolean
 fill_buffer (GZHandle *gz,
              gsize num_bytes)
 {
-  gboolean res;
   gsize count;
 
   z_stream * zstream = &gz->zstream;
@@ -576,7 +569,7 @@ gz_handle_read (GZHandle *gz,
     } else if (z_result != Z_OK) {
       gz->last_z_result = z_result;
     }
-    
+
     if (gz->last_z_result != Z_OK && zstream->avail_out == num_bytes) {
       return result_from_z_result (gz->last_z_result);
     }
@@ -617,7 +610,6 @@ log_load (GIOSchedulerJob *io_job,
   const char *content_type;
   GFileType type;
   GError *err = NULL;
-  GTimeVal timeval;
   gboolean is_archive, can_read;
 
   info = g_file_query_info (f,
@@ -662,8 +654,19 @@ log_load (GIOSchedulerJob *io_job,
   }
 
   log->priv->file_size = g_file_info_get_size (info);
-  g_file_info_get_modification_time (info, &timeval);
-  log->priv->file_time = timeval.tv_sec;
+  #if GLIB_CHECK_VERSION(2,61,2)
+    GDateTime *file_dt;
+    gint64 t;
+    file_dt = g_file_info_get_modification_date_time (info);
+    t = g_date_time_to_unix (file_dt);
+    g_date_time_unref (file_dt);
+    log->priv->file_time = t;
+  #else
+    GTimeVal time_val;
+    g_file_info_get_modification_time (info, &time_val);
+    log->priv->file_time = time_val.tv_sec;
+  #endif
+
   log->priv->display_name = g_strdup (g_file_info_get_display_name (info));
 
   g_object_unref (info);
@@ -728,7 +731,7 @@ log_load (GIOSchedulerJob *io_job,
       err = create_zlib_error ();
       goto out;
     }
- 
+
     g_object_unref (is);
     is = real_is;
 
