@@ -1,25 +1,28 @@
 /* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2; -*- */
-/* logview-window.c - main window of logview
+/* Copyright (C) 1998 Cesar Miquel <miquel@df.uba.ar>
+ * Copyright (C) 2008 Cosimo Cecchi <cosimoc@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 1998  Cesar Miquel  <miquel@df.uba.ar>
- * Copyright (C) 2008  Cosimo Cecchi <cosimoc@gnome.org>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or modify
+ * MATE Utils is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <gtk/gtk.h>
@@ -769,10 +772,10 @@ logview_about (GtkWidget *widget, GtkWidget *window)
                          "version", VERSION,
                          "title", _("About System Log Viewer"),
                          "copyright", _("Copyright \xc2\xa9 1998-2008 Free Software Foundation, Inc.\n"
-                                        "Copyright \xc2\xa9 2011-2020 MATE developers"),
+                                        "Copyright \xc2\xa9 2011-2021 MATE developers"),
                          "license", license_trans,
                          "wrap-license", TRUE,
-                         "comments", _("A system log viewer for MATE."),
+                         "comments", _("View, monitor or analyze your system logs in a gradual manner."),
                          "authors", logview_about_authors,
                          "documenters", logview_about_documenters,
                          "translator_credits", strcmp (logview_about_translator_credits,
