@@ -1,24 +1,24 @@
-/* gdict-utils.c - Utility functions for Gdict
+/* Copyright (C) 2005 Emmanuele Bassi <ebassi@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2005  Emmanuele Bassi <ebassi@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * You should have received a copy of the GNU General Public License
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -89,7 +89,7 @@ gdict_arg_no_debug_cb (const char *key,
                            G_N_ELEMENTS (gdict_debug_keys));
   return TRUE;
 }
-#endif /* CLUTTER_ENABLE_DEBUG */
+#endif /* GDICT_ENABLE_DEBUG */
 
 static GOptionEntry gdict_args[] = {
 #ifdef GDICT_ENABLE_DEBUG
@@ -107,13 +107,11 @@ pre_parse_hook (GOptionContext  *context,
                 gpointer         data,
                 GError         **error)
 {
-  const char *env_string;
-
   if (gdict_is_initialized)
     return TRUE;
 
 #ifdef GDICT_ENABLE_DEBUG
-  env_string = g_getenv ("GDICT_DEBUG");
+  const char *env_string = g_getenv ("GDICT_DEBUG");
   if (env_string != NULL)
     {
       gdict_debug_flags =
@@ -121,8 +119,6 @@ pre_parse_hook (GOptionContext  *context,
                               gdict_debug_keys,
                               G_N_ELEMENTS (gdict_debug_keys));
     }
-#else
-  env_string = NULL;
 #endif /* GDICT_ENABLE_DEBUG */
 
   return TRUE;
@@ -161,7 +157,9 @@ gdict_get_option_group (void)
 
   g_option_group_set_parse_hooks (group, pre_parse_hook, post_parse_hook);
   g_option_group_add_entries (group, gdict_args);
+#ifdef ENABLE_NLS
   g_option_group_set_translation_domain (group, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
   return group;
 }
