@@ -1,27 +1,24 @@
-/* gdict-window.c - main application window
+/* Copyright (C) 2005 Emmanuele Bassi
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * This file is part of MATE Dictionary
+ * This file is part of MATE Utils.
  *
- * Copyright (C) 2005 Emmanuele Bassi
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -133,7 +130,6 @@ gdict_window_dispose (GObject *gobject)
   if (window->settings != NULL)
     {
       g_object_unref (window->settings);
-
       window->settings = NULL;
     }
 
@@ -192,6 +188,8 @@ gdict_window_dispose (GObject *gobject)
       window->busy_cursor = NULL;
     }
 
+  g_clear_pointer (&window->sidebar_page, g_free);
+
   G_OBJECT_CLASS (gdict_window_parent_class)->dispose (gobject);
 }
 
@@ -252,30 +250,6 @@ gdict_window_set_sidebar_visible (GdictWindow *window,
     }
 }
 
-static void
-gdict_window_set_statusbar_visible (GdictWindow *window,
-				    gboolean     is_visible)
-{
-  g_assert (GDICT_IS_WINDOW (window));
-
-  is_visible = !!is_visible;
-
-  if (is_visible != window->statusbar_visible)
-    {
-      GtkAction *action;
-
-      window->statusbar_visible = is_visible;
-
-      if (window->statusbar_visible)
-	gtk_widget_show (window->status);
-      else
-	gtk_widget_hide (window->status);
-
-      action = gtk_action_group_get_action (window->action_group, "ViewStatusbar");
-      gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), window->statusbar_visible);
-    }
-}
-
 static void
 gdict_window_definition_cb (GdictContext    *context,
 			    GdictDefinition *definition,
@@ -1282,11 +1256,11 @@ gdict_window_cmd_escape (GtkAction   *action,
 
 static const GtkActionEntry entries[] =
 {
-  { "File", NULL, N_("_File") },
-  { "Edit", NULL, N_("_Edit") },
-  { "View", NULL, N_("_View") },
-  { "Go", NULL, N_("_Go") },
-  { "Help", NULL, N_("_Help") },
+  { "File", NULL, N_("_File"), NULL, NULL, NULL },
+  { "Edit", NULL, N_("_Edit"), NULL, NULL, NULL },
+  { "View", NULL, N_("_View"), NULL, NULL, NULL },
+  { "Go",   NULL, N_("_Go"),   NULL, NULL, NULL },
+  { "Help", NULL, N_("_Help"), NULL, NULL, NULL },
 
   /* File menu */
   { "FileNew", "document-new", N_("_New"), "<control>N",
