@@ -1,23 +1,26 @@
-/* screenshot-dialog.c - main MATE Screenshot dialog
+/* Copyright (C) 2001-2006 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2001-2006  Jonathan Blandford <jrb@alum.mit.edu>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * You should have received a copy of the GNU General Public License
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <string.h>
 #include <stdlib.h>
 
@@ -27,6 +30,8 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#define GET_WIDGET(x) (GTK_WIDGET (gtk_builder_get_object (dialog->builder, (x))))
+
 enum {
   TYPE_IMAGE_PNG,
   TYPE_TEXT_URI_LIST,
@@ -42,7 +47,7 @@ static GtkTargetEntry drag_types[] =
 
 struct ScreenshotDialog
 {
-  GtkBuilder *ui;
+  GtkBuilder *builder;
   GdkPixbuf *screenshot;
   GdkPixbuf *preview_image;
   GtkWidget *save_widget;
@@ -192,11 +197,11 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
 
   dialog = g_new0 (ScreenshotDialog, 1);
 
-  dialog->ui = gtk_builder_new ();
+  dialog->builder = gtk_builder_new ();
 
   dialog->screenshot = screenshot;
 
-  if (gtk_builder_add_from_resource (dialog->ui, "/org/mate/screenshot/mate-screenshot.ui", &error) == 0)
+  if (gtk_builder_add_from_resource (dialog->builder, "/org/mate/screenshot/mate-screenshot.ui", &error) == 0)
     {
       GtkWidget *dialog;
       dialog = gtk_message_dialog_new (NULL, 0,
@@ -211,7 +216,7 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
       exit (1);
     }
 
-  gtk_builder_set_translation_domain (dialog->ui, GETTEXT_PACKAGE);
+  gtk_builder_set_translation_domain (dialog->builder, GETTEXT_PACKAGE);
 
   width = gdk_pixbuf_get_width (screenshot);
   height = gdk_pixbuf_get_height (screenshot);
@@ -219,11 +224,11 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
   width /= 5;
   height /= 5;
 
-  toplevel = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "toplevel"));
-  aspect_frame = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "aspect_frame"));
-  preview_darea = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "preview_darea"));
-  dialog->filename_entry = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "filename_entry"));
-  file_chooser_box = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "file_chooser_box"));
+  toplevel = GET_WIDGET ("toplevel");
+  aspect_frame = GET_WIDGET ("aspect_frame");
+  preview_darea = GET_WIDGET ("preview_darea");
+  dialog->filename_entry = GET_WIDGET ("filename_entry");
+  file_chooser_box = GET_WIDGET ("file_chooser_box");
 
   dialog->save_widget = gtk_file_chooser_button_new (_("Select a folder"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
   gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog->save_widget), FALSE);
@@ -234,10 +239,10 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
   g_free (current_folder);
 
   gtk_widget_set_size_request (preview_darea, width, height);
+  height = gdk_pixbuf_get_height (screenshot);
+  width = gdk_pixbuf_get_width (screenshot);
   gtk_aspect_frame_set (GTK_ASPECT_FRAME (aspect_frame), 0.0, 0.5,
-			gdk_pixbuf_get_width (screenshot)/
-			(gfloat) gdk_pixbuf_get_height (screenshot),
-			FALSE);
+                        (gfloat) width / (gfloat) height, FALSE);
   g_signal_connect (toplevel, "key_press_event", G_CALLBACK (on_toplevel_key_press_event), dialog);
   g_signal_connect (preview_darea, "draw", G_CALLBACK (on_preview_draw), dialog);
   g_signal_connect (preview_darea, "button_press_event", G_CALLBACK (on_preview_button_press_event), dialog);
@@ -287,7 +292,7 @@ screenshot_dialog_enable_dnd (ScreenshotDialog *dialog)
 
   g_return_if_fail (dialog != NULL);
 
-  preview_darea = GTK_WIDGET (gtk_builder_get_object (dialog->ui, "preview_darea"));
+  preview_darea = GET_WIDGET ("preview_darea");
   gtk_drag_source_set (preview_darea,
 		       GDK_BUTTON1_MASK | GDK_BUTTON3_MASK,
 		       drag_types, G_N_ELEMENTS (drag_types),
@@ -297,7 +302,7 @@ screenshot_dialog_enable_dnd (ScreenshotDialog *dialog)
 GtkWidget *
 screenshot_dialog_get_toplevel (ScreenshotDialog *dialog)
 {
-  return GTK_WIDGET (gtk_builder_get_object (dialog->ui, "toplevel"));
+  return GET_WIDGET ("toplevel");
 }
 
 char *
